@@ -1,6 +1,7 @@
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*facutra_more.h
 *
-*    Copyright (C) 2005 Rizoma Tecnologia Limitada <jonathan@rizoma.cl>
+*    Copyright (C) 2005 Rizoma Tecnologia Limitada <info@rizoma.cl>
 *
 *    This file is part of rizoma.
 *
@@ -16,7 +17,7 @@
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
-*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef FACTURA_MORE_H
@@ -26,5 +27,5 @@
 gint PrintDocument (gint sell_type, gchar *rut, gint total, gint num, Productos *productos);
 
 gchar * PrintFactura (gchar *client, gchar *rut, gchar *address, gchar *giro, gchar *comuna, gchar *fono,
-		   Productos *productos, gint num);
+		   GList *products, gint num);
 #endif
